GdpLint enum

GDP lint issues

Inheritance
Available extensions

Values

placement → const GdpLint

The dependency is not in dependency_overrides

const GdpLint(code: 'gdp_placement', message: 'Not in dependency_overrides')
specifyPrs → const GdpLint

The dependency does not specify any PRs

const GdpLint(code: 'gdp_specify_prs', message: 'No PRs specified')
specifyHash → const GdpLint

The dependency does not specify a commit hash

const GdpLint(code: 'gdp_specify_hash', message: 'Ref is missing or not a commit hash')

Properties

code → String
Lint code
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
message → String
Lint message
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromCode(String code) → GdpLint?
Get a lint from its code
fromDependency(GitDependencyReference dependency) → List<GdpLint>
Generate lints for a dependency

Constants

values → const List<GdpLint>
A constant List of the values in this enum, in order of their declaration.